==> live-usb-maker-gui-antix_0.1.10.tar.xz: live-usb-maker-gui-antix/translations/live-usb-maker-gui-antix_sk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk" version="2.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Program_Name</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="33"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Vyberte cieľovú USB Jednotku&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="43"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Vyberte ISO súbor&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="88"/>
        <location filename="mainwindow.cpp" line="446"/>
        <location filename="mainwindow.cpp" line="464"/>
        <source>Select ISO</source>
        <translation>Vyberte ISO súbor</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="100"/>
        <source>Refresh drive list</source>
        <translation>Obnoviť zoznam diskových jednotiek</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="112"/>
        <location filename="mainwindow.cpp" line="393"/>
        <location filename="mainwindow.cpp" line="399"/>
        <source>Show advanced options</source>
        <translation>Zobraziť Pokročilé Nastavenia</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="130"/>
        <source>Advanced Options</source>
        <translation>Pokročilé Nastavenia</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="139"/>
        <source>Verbosity (less to more):</source>
        <translation>Rozvláčnosť (menej do viac):</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="190"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Veľkosť ESP (uefi) diskového oddielu:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="222"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Vytvoriť súborový systém ext4 aj v prípade, že už existuje</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="229"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Pri aktualizácii LiveUSB uložiť pôvodnú zložku pre bootovanie PC</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="236"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Pre delenie disku použiť gpt namiesto metódy msdos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="239"/>
        <source>GPT partitioning</source>
        <translation>Delenie GPT</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="246"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Aktualizovať (iba zaktualizuje existujúce LiveUSB)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="253"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Nenahradzovať syslinux súbory</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="256"/>
        <source>Keep syslinux files</source>
        <translation>Zachovať sysliux súbory</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="263"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignorovať kontrolu USB/odnímateľné</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="270"/>
        <source>Temporarily disable automounting</source>
        <translation>Dočasne vypnúť automatické pripájanie diskov</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="280"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Nastaviť príznak pmbr_boot disk (pre bootovanie bez UEFI)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="293"/>
        <source>Options</source>
        <translation>Nastavenia</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="308"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Nespúšťať príkazy, ktoré ovplyvňujú USB jednotku</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="311"/>
        <source>Dry run (no change to system)</source>
        <translation>Na sucho (bez zmien v systéme)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="318"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>klon pripojeného LiveUSB do ISO súboru.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="321"/>
        <source>Clone an existing live system</source>
        <translation>Klonovať tento Live systém</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="328"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Pri nastavení šifrovania oddielu bude požadované zadanie hesla pri prvom štarte</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="331"/>
        <source>Encrypt</source>
        <translation>Zakódovať</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="338"/>
        <source>Clone running live system</source>
        <translation>Klon bežiaceho Live systému</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="345"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Iba na čítanie, nebude fungovať persistencia</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="348"/>
        <source>Copy image to USB (dd)</source>
        <translation>Kópia obrazu na USB (dd)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="371"/>
        <source>Percent of USB-device to use:</source>
        <translation>Percentuálne využitie USB jednotky:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="394"/>
        <source>Label ext partition:</source>
        <translation>Názov diskového oddielu:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="442"/>
        <source>For distros other than antiX/MX use &quot;Copy image to USB (dd)&quot; only.</source>
        <translation>Pre distribúcie linuxu iné ako anitX/MX použite voľbu Image (dd).</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="499"/>
        <source>Quit application</source>
        <translation>Zatvoriť aplikáciu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="502"/>
        <source>Close</source>
        <translation>Zatvoriť</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="510"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="542"/>
        <source>Display help </source>
        <translation>Zobraziť nápovedu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="545"/>
        <source>Help</source>
        <translation>Pomocník</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="553"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="569"/>
        <source>Back</source>
        <translation>Naspäť</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="628"/>
        <source>Next</source>
        <translation>Ďalej</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="655"/>
        <source>About this application</source>
        <translation>O tejto aplikácii</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="658"/>
        <source>About...</source>
        <translation>O Programe</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="666"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="72"/>
        <location filename="mainwindow.cpp" line="239"/>
        <location filename="mainwindow.cpp" line="379"/>
        <source>Failure</source>
        <translation>Neúspech</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="72"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>Zdroj a cieľové umiestnenie sú na rovnakej jednotke, prosím zmeňte zadanie. </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="94"/>
        <source>Writing %1 using 'dd' command to /dev/%2,

Please wait until the the process is completed</source>
        <translation>Zapisujem %1 na /dev/%2 s použitím príkazu &apos;dd&apos;
Prosím vydržte pokiaľ proces zápisu nebude dokončený</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="237"/>
        <source>Success</source>
        <translation>Úspech</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="237"/>
        <source>LiveUSB creation successful!</source>
        <translation>Live-USB bolo úspešne vytvorené!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="239"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Počas tvorby LiveUSB sa vyskytla chyba</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="285"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="285"/>
        <source>Please select a USB device to write to</source>
        <translation>Prosím vyberte USB jednotku k zápisu</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="288"/>
        <location filename="mainwindow.cpp" line="458"/>
        <source>clone</source>
        <translation>klonovať</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="327"/>
        <source>About</source>
        <translation>O Programe</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="328"/>
        <source>Version: </source>
        <translation>Verzia:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="329"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Program pre vytvorenie LiveUSB z ISO súboru alebo ďalšieho LiveUSB, CD, DVD z bežiaceho Live systému.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="331"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="332"/>
        <location filename="mainwindow.cpp" line="338"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="333"/>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="368"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Vyberte ISO súbor pre zápis na USB </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="374"/>
        <location filename="mainwindow.cpp" line="442"/>
        <source>Select Source Directory</source>
        <translation>Vyberte zdrojovú zložku</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="379"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation>Súbor %1/antiX/linuxfs nebol nájdený</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="395"/>
        <source>Hide advanced options</source>
        <translation>Skryť Pokročilé Nastavenia</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="441"/>
        <location filename="mainwindow.cpp" line="456"/>
        <source>Select Source</source>
        <translation>Vyberte zdroj</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="445"/>
        <location filename="mainwindow.cpp" line="462"/>
        <source>Select ISO file</source>
        <translation>Vyberte ISO súbor</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="main.cpp" line="52"/>
        <source>You must run this program as root.</source>
        <translation>Tento program musíte spustiť ako root užívateľ.</translation>
    </message>
</context>
</TS>

==> live-usb-maker-gui-antix_24.06.15.tar.xz: live-usb-maker-gui-antix/translations/live-usb-maker-gui-antix_sk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk" version="2.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Program_Name</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Zatvoriť aplikáciu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Zatvoriť</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="56"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="88"/>
        <source>Display help </source>
        <translation>Zobraziť nápovedu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="91"/>
        <source>Help</source>
        <translation>Pomocník</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="98"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="114"/>
        <source>Back</source>
        <translation>Naspäť</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="172"/>
        <source>Next</source>
        <translation>Ďalej</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="198"/>
        <source>About this application</source>
        <translation>O tejto aplikácii</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="201"/>
        <source>About...</source>
        <translation>O Programe</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="208"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="239"/>
        <location filename="mainwindow.cpp" line="462"/>
        <location filename="mainwindow.cpp" line="481"/>
        <source>Select ISO</source>
        <translation>Vyberte ISO súbor</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="250"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Vyberte cieľovú USB Jednotku&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="260"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Vyberte ISO súbor&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="289"/>
        <source>Advanced Options</source>
        <translation>Pokročilé Nastavenia</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="307"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Vytvoriť súborový systém ext4 aj v prípade, že už existuje</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="314"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Pri aktualizácii LiveUSB uložiť pôvodnú zložku pre bootovanie PC</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="321"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Pre delenie disku použiť gpt namiesto metódy msdos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="324"/>
        <source>GPT partitioning</source>
        <translation>Delenie GPT</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="331"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Aktualizovať (iba zaktualizuje existujúce LiveUSB)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="338"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Nenahradzovať syslinux súbory</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="341"/>
        <source>Keep syslinux files</source>
        <translation>Zachovať sysliux súbory</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="348"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignorovať kontrolu USB/odnímateľné</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="355"/>
        <source>Temporarily disable automounting</source>
        <translation>Dočasne vypnúť automatické pripájanie diskov</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="365"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Nastaviť príznak pmbr_boot disk (pre bootovanie bez UEFI)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="372"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.ui" line="398"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Veľkosť ESP (uefi) diskového oddielu:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="418"/>
        <source>Verbosity (less to more):</source>
        <translation>Rozvláčnosť (menej do viac):</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="457"/>
        <source>vfat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.ui" line="462"/>
        <source>exfat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.ui" line="467"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="472"/>
        <source>ntfs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.ui" line="493"/>
        <source>Make separate data partition (percent)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.ui" line="500"/>
        <source>Format</source>
        <translation>Formát zobrazenia</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="510"/>
        <source>Refresh drive list</source>
        <translation>Obnoviť zoznam diskových jednotiek</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="524"/>
        <location filename="mainwindow.cpp" line="407"/>
        <source>Show advanced options</source>
        <translation>Zobraziť Pokročilé Nastavenia</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="544"/>
        <source>Mode</source>
        <translation>Typ LiveUSB </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="559"/>
        <source>Full-featured mode - writable LiveUSB</source>
        <translation>Všetky funkcie - prepisovateľné LiveUSB</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="569"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Iba na čítanie, nebude fungovať persistencia</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="572"/>
        <source>Image mode - read-only LiveUSB (dd)</source>
        <translation>Image - LiveUSB iba na čítanie (dd)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="586"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Pre distribúcie linuxu iné ako anitX/MX použite voľbu Image (dd).</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="634"/>
        <source>Options</source>
        <translation>Nastavenia</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="669"/>
        <source>Percent of USB-device to use:</source>
        <translation>Percentuálne využitie USB jednotky:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="676"/>
        <source>Label ext partition:</source>
        <translation>Názov diskového oddielu:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="724"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Nespúšťať príkazy, ktoré ovplyvňujú USB jednotku</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="727"/>
        <source>Dry run (no change to system)</source>
        <translation>Na sucho (bez zmien v systéme)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="734"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>klon pripojeného LiveUSB do ISO súboru.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="737"/>
        <source>Clone an existing live system</source>
        <translation>Klonovať tento Live systém</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="744"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Pri nastavení šifrovania oddielu bude požadované zadanie hesla pri prvom štarte</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="747"/>
        <source>Encrypt</source>
        <translation>Zakódovať</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="754"/>
        <source>Clone running live system</source>
        <translation>Klon bežiaceho Live systému</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="86"/>
        <location filename="mainwindow.cpp" line="267"/>
        <location filename="mainwindow.cpp" line="392"/>
        <source>Failure</source>
        <translation>Neúspech</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="86"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>Zdroj a cieľové umiestnenie sú na rovnakej jednotke, prosím zmeňte zadanie. </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="111"/>
        <source>Writing %1 using 'dd' command to /dev/%2,

Please wait until the the process is completed</source>
        <translation>Zapisujem %1 na /dev/%2 s použitím príkazu &apos;dd&apos;
Prosím vydržte pokiaľ proces zápisu nebude dokončený</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="265"/>
        <source>Success</source>
        <translation>Úspech</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="265"/>
        <source>LiveUSB creation successful!</source>
        <translation>Live-USB bolo úspešne vytvorené!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="267"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Počas tvorby LiveUSB sa vyskytla chyba</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="316"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="316"/>
        <source>Please select a USB device to write to</source>
        <translation>Prosím vyberte USB jednotku k zápisu</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="319"/>
        <location filename="mainwindow.cpp" line="475"/>
        <source>clone</source>
        <translation>klonovať</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="355"/>
        <source>About %1</source>
        <translation>Okolo %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="356"/>
        <source>Version: </source>
        <translation>Verzia:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="357"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Program pre vytvorenie LiveUSB z ISO súboru alebo ďalšieho LiveUSB, CD, DVD z bežiaceho Live systému.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="359"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="360"/>
        <source>%1 License</source>
        <translation>%1 Licencia</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="368"/>
        <source>%1 Help</source>
        <translation>%1 Pomoc</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="379"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Vyberte ISO súbor pre zápis na USB </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="387"/>
        <location filename="mainwindow.cpp" line="458"/>
        <source>Select Source Directory</source>
        <translation>Vyberte zdrojovú zložku</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="392"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation>Súbor %1/antiX/linuxfs nebol nájdený</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="413"/>
        <source>Hide advanced options</source>
        <translation>Skryť Pokročilé Nastavenia</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="457"/>
        <location filename="mainwindow.cpp" line="473"/>
        <source>Select Source</source>
        <translation>Vyberte zdroj</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="461"/>
        <location filename="mainwindow.cpp" line="479"/>
        <source>Select ISO file</source>
        <translation>Vyberte ISO súbor</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="about.cpp" line="32"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="about.cpp" line="33"/>
        <location filename="about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>História zmien</translation>
    </message>
    <message>
        <location filename="about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <location filename="about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Zatvoriť</translation>
    </message>
    <message>
        <location filename="main.cpp" line="75"/>
        <source>You must run this program as root.</source>
        <translation>Tento program musíte spustiť ako root užívateľ.</translation>
    </message>
</context>
</TS>
